@@ -14,10 +14,14 @@
 void init_analyze(Sentence);
 void free_analyze(Sentence);
 
-void          extract_thin_linkage(Sentence, Parse_Options, Linkage);
-void          extract_fat_linkage (Sentence, Parse_Options, Linkage);
-Linkage_info  analyze_fat_linkage (Sentence, Parse_Options, int pass);
 Linkage_info  analyze_thin_linkage(Sentence, Parse_Options, int pass);
+void          extract_thin_linkage(Sentence, Parse_Options, Linkage);
+void          free_DIS_tree(DIS_node *);
 
 void zero_sublinkage(Sublinkage *s);
 
+#ifdef USE_FAT_LINKAGES
+Linkage_info  analyze_fat_linkage (Sentence, Parse_Options, int pass);
+void          extract_fat_linkage (Sentence, Parse_Options, Linkage);
+#endif /* USE_FAT_LINKAGES */
+
