@@ -62,6 +62,7 @@ struct Parse_Options_s
 {
 	int verbosity;         /* Level of detail to give about the computation 0 */
 	int use_sat_solver;    /* Use the Boolean SAT based parser */
+	int use_viterbi;       /* Use the Viterbi decoder-based parser */
 	int linkage_limit;     /* The maximum number of linkages processed 100 */
 	float disjunct_cost;   /* Max disjunct cost to allow */
 	int use_fat_links;     /* Look for fat linkages */
@@ -95,7 +96,7 @@ struct Parse_Options_s
 	int screen_width;             /* width of screen for displaying linkages */
 	int display_on;               /* if true, output graphical linkage diagram */
 	int display_postscript;       /* if true, output postscript linkage */
-	int display_constituents;     /* if true, output treebank-style constituent structure */
+	ConstituentDisplayStyle display_constituents;     /* style for displaying constituent structure */
 	int display_bad;              /* if true, bad linkages are displayed */
 	int display_disjuncts;        /* if true, print disjuncts that were used */
 	int display_links;            /* if true, a list o' links is printed out */
@@ -125,21 +126,6 @@ struct Dictionary_s
 	Corpus *        corpus; /* Statistics database */
 #endif
 
-#if DONT_USE_REGEX_GUESSING
-	/* English language morphology bits
-	 * replaced by regex-based morpho guesser
-	 * Dead code, remove at leisure.
-	 */
-	int             capitalized_word_defined;
-	int             pl_capitalized_word_defined;
-	int             hyphenated_word_defined;
-	int             number_word_defined;
-	int             ing_word_defined;
-	int             s_word_defined;
-	int             ed_word_defined;
-	int             ly_word_defined;
-#endif /* DONT_USE_REGEX_GUESSING */
-
 	int             left_wall_defined;
 	int             right_wall_defined;
 
@@ -174,7 +160,8 @@ struct Dictionary_s
 	/* Private data elements that come in play only while the
 	 * dictionary is being read, and are not otherwise used.
 	 */
-	FILE *          fp;
+	const wchar_t * input;
+	const wchar_t * pin;
 	char            token[MAX_TOKEN_LENGTH];
 	int             is_special;        /* boolean */
 	wint_t          already_got_it;
@@ -232,11 +219,13 @@ struct Sentence_s
 	const char *orig_sentence;  /* Copy of original sentence */
 	int    length;              /* number of words */
 	Word   word[MAX_SENTENCE];  /* array of words after tokenization */
+#ifdef USE_FAT_LINKAGES
 	char * is_conjunction;      /* Array of flags, one per word; set to
 	                               TRUE if conjunction, as defined by dictionary */
 	char** deletable;           /* deletable regions in a sentence with conjunction */
 	char** dptr;                /* private pointer for mem management only */
 	char** effective_dist;
+#endif /* USE_FAT_LINKAGES */
 	int    num_linkages_found;  /* total number before postprocessing.  This
 	                               is returned by the count() function */
 	int    num_linkages_alloced;/* total number of linkages allocated.
@@ -254,7 +243,9 @@ struct Sentence_s
 	Parse_info     parse_info;  /* set of parses for the sentence */
 	Linkage_info * link_info;   /* array of valid and invalid linkages (sorted) */
 	String_set *   string_set;  /* used for word names, not connectors */
+#ifdef USE_FAT_LINKAGES
 	And_data       and_data;    /* used to keep track of fat disjuncts */
+#endif /* USE_FAT_LINKAGES */
 	char  q_pruned_rules;       /* don't prune rules more than once in p.p. */
 	int   post_quote[MAX_SENTENCE]; /* Used only by tokenizer. */
 
@@ -333,6 +324,10 @@ struct Postprocessor_s
  *
  **********************************************************/
 
+/* XXX FIXME When fat links are removed, therre will only ever be
+ * just one sublinkage, and so this struct can be merged into 
+ * Linkage_s below, and removed from the API.
+ */
 struct Sublinkage_s
 {
 	int       num_links;          /* Number of links in array */
