@@ -11,6 +11,12 @@
 /*                                                                       */
 /*************************************************************************/
 
+/* This file is somewhat misnamed, as everything here defines the
+ * link-private, internal-use-only "api", which is subject to change
+ * from revision to revision. No external code should link to this
+ * stuff.
+ */
+
 #ifndef _API_TYPES_H_
 #define _API_TYPES_H_
 
@@ -25,13 +31,7 @@
 #define MAX_LINKS (2*MAX_SENTENCE-3) /* maximum number of links allowed */
 
 
-/* "public" typedefs */
-typedef enum
-{
-	VDAL=1, /* Sort by Violations, Disjunct cost, And cost, Link cost */
-	CORPUS, /* Sort by Corpus cost */
-}  Cost_Model_type;
-
+/* Widely used private typedefs */
 typedef struct And_data_s And_data;
 typedef struct Connector_struct Connector;
 typedef struct Cost_Model_s Cost_Model;
@@ -49,7 +49,7 @@ typedef struct Regex_node_s Regex_node;
 typedef struct Resources_s * Resources;
 typedef struct Sublinkage_s Sublinkage;
 
-/* Some private typedefs */
+/* Some of the more obscure typedefs */
 typedef char Boolean;
 typedef struct analyze_context_s analyze_context_t;
 typedef struct count_context_s count_context_t;
