@@ -14,7 +14,7 @@
 /* stuff for transforming a dictionary entry into a disjunct list */
 
 #include <math.h>
-#include <link-grammar/api.h>
+#include "api.h"
 #include "disjunct-utils.h"
 #include "utilities.h" /* For Win32 compatibility features */
 
@@ -346,8 +346,6 @@ static Connector * extract_connectors(Tconnector *e, int c)
 		e1->next = extract_connectors(e->next,c);
 		e1->multi = e->multi;
 		e1->string = e->string;
-		e1->label = NORMAL_LABEL;
-		e1->priority = THIN_priority;
 		e1->word = 0;
 		return e1;
 	}
