@@ -28,8 +28,10 @@ struct Table_connector_s
 
 struct count_context_s
 {
+#ifdef USE_FAT_LINKAGES
 	char ** deletable;
 	char ** effective_dist; 
+#endif /* USE_FAT_LINKAGES */
 	Word *  local_sent;
 	int     null_block;
 	int     islands_ok;
@@ -92,6 +94,7 @@ int x_match(Sentence sent, Connector *a, Connector *b)
 	return do_match(sent, a, b, 0, 0);
 }
 
+#ifdef USE_FAT_LINKAGES
 void count_set_effective_distance(Sentence sent)
 {
 	sent->count_ctxt->effective_dist = sent->effective_dist;
@@ -101,6 +104,7 @@ void count_unset_effective_distance(Sentence sent)
 {
 	sent->count_ctxt->effective_dist = NULL;
 }
+#endif /* USE_FAT_LINKAGES */
 
 /*
  * Returns TRUE if s and t match according to the connector matching
@@ -111,15 +115,17 @@ void count_unset_effective_distance(Sentence sent)
  * It works as follows:  The labels must match.  The priorities must be
  * compatible (both THIN_priority, or one UP_priority and one DOWN_priority).
  * The sequence of upper case letters must match exactly.  After these comes
- * a sequence of lower case letters "*"s or "^"s.  The matching algorithm
+ * a sequence of lower case letters or "*"s.  The matching algorithm
  * is different depending on which of the two priority cases is being
  * considered.  See the comments below. 
  */
 int do_match(Sentence sent, Connector *a, Connector *b, int aw, int bw)
 {
 	const char *s, *t;
-	int x, y, dist;
-	count_context_t *ctxt;
+	int x, y;
+#ifdef USE_FAT_LINKAGES
+	int dist;
+#endif /* USE_FAT_LINKAGES */
 
 	if (a->label != b->label) return FALSE;
 
@@ -133,22 +139,25 @@ int do_match(Sentence sent, Connector *a, Connector *b, int aw, int bw)
 		t++;
 	}
 
-	ctxt = sent->count_ctxt;
-
 	x = a->priority;
 	y = b->priority;
 
+#ifdef USE_FAT_LINKAGES
+
 	/* Probably not necessary, as long as 
 	 * effective_dist[0][0]=0 and is defined */
 	if (aw == 0 && bw == 0) {
 		dist = 0;
 	} else {
+		count_context_t *ctxt;
+		ctxt = sent->count_ctxt;
 		assert(aw < bw, "match() did not receive params in the natural order.");
 		dist = ctxt->effective_dist[aw][bw];
 	}
 	/*	printf("M: a=%4s b=%4s  ap=%d bp=%d  aw=%d  bw=%d  a->ll=%d b->ll=%d  dist=%d\n",
 		   s, t, x, y, aw, bw, a->length_limit, b->length_limit, dist); */
 	if (dist > a->length_limit || dist > b->length_limit) return FALSE;
+#endif /* USE_FAT_LINKAGES */
 
 	if ((x == THIN_priority) && (y == THIN_priority))
 	{
@@ -158,15 +167,25 @@ int do_match(Sentence sent, Connector *a, Connector *b, int aw, int bw)
 		   they're equal.  ("^" can be used in the dictionary just like
 		   any other connector.)
 		   */
-		while ((*s!='\0') && (*t!='\0')) {
+		while ((*s != '\0') && (*t != '\0'))
+		{
+#ifdef USE_FAT_LINKAGES
 			if ((*s == '*') || (*t == '*') ||
-				((*s == *t) && (*s != '^'))) {
+				((*s == *t) && (*s != '^')))
+#else
+			if ((*s == '*') || (*t == '*') || (*s == *t))
+#endif /* USE_FAT_LINKAGES */
+			{
 				s++;
 				t++;
-			} else return FALSE;
+			}
+			else
+				return FALSE;
 		}
 		return TRUE;
-	} else if ((x==UP_priority) && (y==DOWN_priority)) {
+	}
+	else if ((x == UP_priority) && (y == DOWN_priority))
+	{
 		/*
 		   As you go up (namely from x to y) the set of strings that
 		   match (in the normal THIN sense above) should get no larger.
@@ -178,8 +197,14 @@ int do_match(Sentence sent, Connector *a, Connector *b, int aw, int bw)
 		   length.  This is currently true, but perhaps for safty
 		   this assumption should be removed.
 		   */
-		while ((*s!='\0') && (*t!='\0')) {
-			if ((*s == *t) || (*s == '*') || (*t == '^')) {
+		while ((*s != '\0') && (*t != '\0'))
+		{
+#ifdef USE_FAT_LINKAGES
+			if ((*s == *t) || (*s == '*') || (*t == '^'))
+#else
+			if ((*s == *t) || (*s == '*'))
+#endif /* USE_FAT_LINKAGES */
+			{
 				s++;
 				t++;
 			} else return FALSE;
@@ -188,9 +213,13 @@ int do_match(Sentence sent, Connector *a, Connector *b, int aw, int bw)
 	}
 	else if ((y == UP_priority) && (x == DOWN_priority))
 	{
-		while ((*s!='\0') && (*t!='\0'))
+		while ((*s != '\0') && (*t != '\0'))
 		{
+#ifdef USE_FAT_LINKAGES
 			if ((*s == *t) || (*t == '*') || (*s == '^'))
+#else
+			if ((*s == *t) || (*t == '*'))
+#endif /* USE_FAT_LINKAGES */
 			{
 				s++;
 				t++;
@@ -260,6 +289,7 @@ s64 table_lookup(Sentence sent,
 	if (t == NULL) return -1; else return t->count;
 }
 
+#ifdef USE_FAT_LINKAGES
 /**
  * Stores the value in the table.  Unlike table_store, it assumes 
  * it's already there
@@ -273,6 +303,7 @@ static void table_update(count_context_t *ctxt, int lw, int rw,
 	assert(t != NULL, "This entry is supposed to be in the table.");
 	t->count = count;
 }
+#endif /* USE_FAT_LINKAGES */
 
 /**
  * Returns 0 if and only if this entry is in the hash table 
@@ -289,7 +320,6 @@ static s64 pseudocount(Sentence sent,
 static s64 do_count(Sentence sent, int lw, int rw,
                     Connector *le, Connector *re, int null_count)
 {
-	Disjunct * d;
 	s64 total, pseudototal;
 	int start_word, end_word, w;
 	s64 leftcount, rightcount;
@@ -355,6 +385,7 @@ static s64 do_count(Sentence sent, int lw, int rw,
 		}
 		else
 		{
+			Disjunct * d;
 			total = 0;
 			w = lw+1;
 			for (d = ctxt->local_sent[w].d; d != NULL; d = d->next)
@@ -393,8 +424,9 @@ static s64 do_count(Sentence sent, int lw, int rw,
 	for (w = start_word; w < end_word; w++)
 	{
 		m1 = m = form_match_list(sent, w, le, lw, re, rw);
-		for (; m!=NULL; m=m->next)
+		for (; m != NULL; m = m->next)
 		{
+			Disjunct * d;
 			d = m->d;
 			for (lcost = 0; lcost <= null_count; lcost++)
 			{
@@ -468,13 +500,13 @@ static s64 do_count(Sentence sent, int lw, int rw,
 				}
 			}
 		}
-
 		put_match_list(sent, m1);
 	}
 	t->count = total;
 	return total;
 }
 
+
 /** 
  * Returns the number of ways the sentence can be parsed with the
  * specified null count. Assumes that the hash table has already been
@@ -486,10 +518,12 @@ s64 do_parse(Sentence sent, int null_count, Parse_Options opts)
 	s64 total;
 	count_context_t *ctxt = sent->count_ctxt;
 
-	count_set_effective_distance(sent);
 	ctxt->current_resources = opts->resources;
 	ctxt->local_sent = sent->word;
+#ifdef USE_FAT_LINKAGES
+	count_set_effective_distance(sent);
 	ctxt->deletable = sent->deletable;
+#endif /* USE_FAT_LINKAGES */
 	ctxt->null_block = opts->null_block;
 	ctxt->islands_ok = opts->islands_ok;
 
@@ -500,6 +534,7 @@ s64 do_parse(Sentence sent, int null_count, Parse_Options opts)
 	return total;
 }
 
+#ifdef USE_FAT_LINKAGES
 /**
    CONJUNCTION PRUNING.
 
@@ -716,6 +751,7 @@ static void mark_region(Sentence sent,
 		put_match_list(sent, m1);
 	}
 }
+#endif /* USE_FAT_LINKAGES */
 
 void delete_unmarked_disjuncts(Sentence sent)
 {
@@ -738,6 +774,7 @@ void delete_unmarked_disjuncts(Sentence sent)
 	}
 }
 
+#ifdef USE_FAT_LINKAGES
 /**
  * We've already built the sentence disjuncts, and we've pruned them
  * and power_pruned(GENTLE) them also.  The sentence contains a
@@ -808,6 +845,7 @@ void conjunction_prune(Sentence sent, Parse_Options opts)
 	ctxt->deletable = NULL;
 	count_unset_effective_distance(sent);
 }
+#endif /* USE_FAT_LINKAGES */
 
 void init_count(Sentence sent)
 {
