@@ -52,7 +52,7 @@ void lg_compute_disjunct_strings(Sentence sent, Linkage_info *lifo)
 	if (lifo->disjunct_list_str) return;
 	lifo->nwords = nwords;
 	lifo->disjunct_list_str = (char **) malloc(nwords * sizeof(char *));
-	bzero(lifo->disjunct_list_str, nwords * sizeof(char *));
+	memset(lifo->disjunct_list_str, 0, nwords * sizeof(char *));
 
 	djcount = (int *) malloc (sizeof(int) * (nwords + 2*nwords*nlinks));
 	djlist = djcount + nwords;
@@ -77,12 +77,12 @@ void lg_compute_disjunct_strings(Sentence sent, Linkage_info *lifo)
 		if (nwords <= rword) continue;
 
 		djlist[lword*nlinks + slot] = i;
-      djloco[lword*nlinks + slot] = rword;
+		djloco[lword*nlinks + slot] = rword;
 		djcount[lword] ++;
 
 		slot = djcount[rword];
 		djlist[rword*nlinks + slot] = i;
-      djloco[rword*nlinks + slot] = lword;
+		djloco[rword*nlinks + slot] = lword;
 		djcount[rword] ++;
 
 #ifdef DEBUG
