@@ -43,11 +43,6 @@ link_public_api(const char *)
  *
  ***********************************************************************/
 
-link_public_api(Dictionary)
-     dictionary_create(const char * dict_name,
-                       const char * pp_name,
-                       const char * cons_name,
-                       const char * affix_name);
 link_public_api(Dictionary)
      dictionary_create_lang(const char * lang);
 link_public_api(Dictionary)
@@ -145,6 +140,10 @@ link_public_api(void)
      parse_options_set_use_sat_parser(Parse_Options opts, int use_sat_solver);
 link_public_api(int)
      parse_options_get_use_sat_parser(Parse_Options opts);
+link_public_api(void)
+     parse_options_set_use_viterbi(Parse_Options opts, int use_viterbi);
+link_public_api(int)
+     parse_options_get_use_viterbi(Parse_Options opts);
 link_public_api(int)
      parse_options_timer_expired(Parse_Options opts);
 link_public_api(int)
@@ -185,6 +184,16 @@ link_public_api(void)
  *
  ***********************************************************************/
 
+typedef enum
+{
+	NO_DISPLAY = 0,        /** Display is disabled */
+	MULTILINE = 1,         /** multi-line, indented display */
+	BRACKET_TREE = 2,      /** single-line, bracketed tree */
+	SINGLE_LINE = 3,       /** single line, round parenthesis */
+   MAX_STYLES = 3         /* this must always be last, largest */
+} ConstituentDisplayStyle;
+
+
 link_public_api(void)
      parse_options_set_batch_mode(Parse_Options opts, int val);
 link_public_api(int)
@@ -202,8 +211,8 @@ link_public_api(void)
 link_public_api(int)
      parse_options_get_display_postscript(Parse_Options opts);
 link_public_api(void)
-     parse_options_set_display_constituents(Parse_Options opts, int val);
-link_public_api(int)
+     parse_options_set_display_constituents(Parse_Options opts, ConstituentDisplayStyle val);
+link_public_api(ConstituentDisplayStyle)
      parse_options_get_display_constituents(Parse_Options opts);
 link_public_api(void)
      parse_options_set_display_bad(Parse_Options opts, int val);
@@ -339,7 +348,7 @@ link_public_api(char *)
 link_public_api(void)
      linkage_free_senses(char *str);
 link_public_api(char *)
-     linkage_print_constituent_tree(Linkage linkage, int mode);
+     linkage_print_constituent_tree(Linkage linkage, ConstituentDisplayStyle mode);
 link_public_api(void)
      linkage_free_constituent_tree_str(char *str);
 link_public_api(char *)
@@ -441,6 +450,15 @@ link_public_api(void)
  *
  ********************************************************/
 
+/* Fails to include the regex file name, which is needed in any
+ * practical application.  Thus, this call is deprecated.
+ * XXX TBD: this will go away in Version 5.0. */
+link_public_api(Dictionary)
+     dictionary_create(const char * dict_name,
+                       const char * pp_name,
+                       const char * cons_name,
+                       const char * affix_name);
+
 /* Both are deprecated, exported only for backwards-compat w/Java API. */
 link_public_api(int)
      dictionary_is_past_tense_form(Dictionary dict, const char * str);
