@@ -103,19 +103,6 @@
 #define ANDABLE_CONNECTORS_WORD ("ANDABLE-CONNECTORS")
 #define UNLIMITED_CONNECTORS_WORD ("UNLIMITED-CONNECTORS")
 
-#if DONT_USE_REGEX_GUESSING
-/* English-language-specific morphology guessing */
-/* Obsolete, replaced by regex-based morphology handler */
-#define PROPER_WORD      ("CAPITALIZED-WORDS")
-#define PL_PROPER_WORD      ("PL-CAPITALIZED-WORDS")
-#define HYPHENATED_WORD  ("HYPHENATED-WORDS")
-#define NUMBER_WORD      ("NUMBERS")
-#define ING_WORD         ("ING-WORDS")
-#define S_WORD           ("S-WORDS")
-#define ED_WORD          ("ED-WORDS")
-#define LY_WORD          ("LY-WORDS")
-#endif /* DONT_USE_REGEX_GUESSING */
-
 #define UNKNOWN_WORD     ("UNKNOWN-WORD")
 
 #define MAX_PATH_NAME 200     /* file names (including paths)
@@ -326,7 +313,9 @@ struct Linkage_info_struct
     int index;
     Boolean fat;
     Boolean canonical;
+#ifdef USE_FAT_LINKAGES
     Boolean improper_fat_linkage;
+#endif /* USE_FAT_LINKAGES */
     Boolean inconsistent_domains;
     short N_violations;
     short null_cost, unused_word_cost, and_cost, link_cost;
