@@ -12,11 +12,15 @@
 /*                                                                       */
 /*************************************************************************/
 
+#include <ctype.h>
 #include <limits.h>
 #include <locale.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
 
 #ifdef USE_PTHREADS
 #include <pthread.h>
@@ -66,7 +70,7 @@ void safe_strcpy(char *u, const char * v, size_t usize)
 	u[usize-1] = '\0';
 }
 
-/** 
+/**
  * A version of strlcpy, for those systems that don't have it.
  */
 size_t lg_strlcpy(char * dest, const char *src, size_t size)
@@ -79,7 +83,7 @@ size_t lg_strlcpy(char * dest, const char *src, size_t size)
 	}
 	if (i < size) { dest[i] = 0x0; size = i; }
 	else if (0 < size) { size --; dest[size] = 0x0;}
-	return size; 
+	return size;
 }
 
 /**
@@ -151,6 +155,28 @@ strtok_r (char *s, const char *delim, char **saveptr)
 
 #endif /* _WIN32 should be !HAVE_STROTOK_R */
 
+#ifdef _WIN32  /* should be !defined(HAVE_STRNDUP) */
+
+/* Emulates glibc's strndup() */
+char *
+strndup (char *str, size_t size)
+{
+	char *result = (char *) NULL;
+
+	if ((char *) NULL == str) return (char *) NULL;
+
+	size_t len = strlen (str);
+	if (!len) return strdup ("");
+	if (size > len) size = len;
+
+	result = (char *) malloc ((size + 1) * sizeof (char));
+	memcpy (result, str, size);
+	result[size] = 0x0;
+	return result;
+}
+
+#endif /* _WIN32 should be !HAVE_STRNDUP */
+
 /* ============================================================= */
 /* UTF8 utilities */
 
@@ -222,7 +248,7 @@ void upcase_utf8_str(char *to, const char * from, size_t usize)
 
 /* ============================================================= */
 /* Memory alloc routines below. These routines attempt to keep
- * track of how much space is getting used during a parse. 
+ * track of how much space is getting used during a parse.
  *
  * This code is probably obsolescent, and should probably be dumped.
  * No one (that I know of) looks at the space usage; its one of the
@@ -536,7 +562,7 @@ char * dictionary_get_data_dir(void)
 
 	if (custom_data_dir != NULL) {
 		data_dir = safe_strdup(custom_data_dir);
-		return data_dir; 
+		return data_dir;
 	}
 	
 #ifdef ENABLE_BINRELOC
@@ -544,17 +570,58 @@ char * dictionary_get_data_dir(void)
 #elif defined(_WIN32)
 	/* Dynamically locate library and return containing directory */
 	hInstance = GetModuleHandle("link-grammar.dll");
-	if(hInstance != NULL)
+	if (hInstance != NULL)
 	{
 		char dll_path[MAX_PATH];
 
-		if(GetModuleFileName(hInstance,dll_path,MAX_PATH)) {
+		if (GetModuleFileName(hInstance, dll_path, MAX_PATH))
+		{
 #ifdef _DEBUG
-			prt_error("Info: GetModuleFileName=%s\n", (dll_path?dll_path:"NULL"));
+			prt_error("Info: GetModuleFileName=%s\n", (dll_path ? dll_path : "NULL"));
 #endif
 			data_dir = path_get_dirname(dll_path);
 		}
 	}
+	else
+	{
+		/* BHayes added else block for when link-grammar.dll is not found 11apr11 */
+		/* This requests module handle for the current program */
+		hInstance = GetModuleHandle(NULL);
+		if (hInstance != NULL)
+		{
+			char prog_path16[MAX_PATH];
+			printf("  found ModuleHandle for current program so try to get Filename for current program \n");
+			if (GetModuleFileName(hInstance, prog_path16, MAX_PATH))
+			{
+				char * data_dir16 = NULL;
+				// convert 2-byte to 1-byte encoding of prog_path
+				char prog_path[MAX_PATH/2];
+				int i, k;
+				for (i = 0; i < MAX_PATH; i++)
+				{
+					k = i + i;
+					if (prog_path16[k] == 0 )
+					{
+						prog_path[i] = 0;
+						break; // found the string ending null char
+					}
+					// XXX this cannot possibly be correct for UTF-16 filepaths!! ?? FIXME
+					prog_path[i] = prog_path16[k];
+				}
+#ifdef _DEBUG
+				prt_error("Info: GetModuleFileName=%s\n", (prog_path ? prog_path : "NULL"));
+#endif
+				data_dir16 = path_get_dirname(prog_path);
+				if (data_dir16 != NULL)
+				{
+					printf("   found dir for current prog %s\n", data_dir16);
+				}
+				return data_dir16;  // return path of data directory here instead of below
+			} else {
+				printf("   FAIL GetModuleFileName for current program \n");
+			}
+		}
+   }  /* BHayes - end added else block */
 #endif
 
 	return data_dir;
@@ -576,7 +643,7 @@ char * dictionary_get_data_dir(void)
  * sequence of directories is specified in a dictpath string, in
  * which each directory is followed by a ":".
  */
-void * object_open(const char *filename, 
+void * object_open(const char *filename,
                    void * (*opencb)(const char *, void *),
                    void * user_data)
 {
@@ -603,8 +670,8 @@ void * object_open(const char *filename,
 	 * Unix: starts with leading slash.
 	 * Windows: starts with C:\  except that the drive letter may differ.
 	 */
-	if ((filename[0] == '/') || ((filename[1] == ':') && (filename[2] == '\\'))) 
-   {
+	if ((filename[0] == '/') || ((filename[1] == ':') && (filename[2] == '\\')))
+	{
 		/* fopen returns NULL if the file does not exist. */
 		fp = opencb(filename, user_data);
 		if (fp) return fp;
@@ -616,8 +683,8 @@ void * object_open(const char *filename,
 		prt_error("Info: data_dir=%s\n", (data_dir?data_dir:"NULL"));
 #endif
 		if (data_dir) {
-			snprintf(fulldictpath, MAX_PATH_NAME, 
-			         "%s%c%s%c", data_dir, PATH_SEPARATOR, 
+			snprintf(fulldictpath, MAX_PATH_NAME,
+			         "%s%c%s%c", data_dir, PATH_SEPARATOR,
 			                    DEFAULTPATH, PATH_SEPARATOR);
 			free(data_dir);
 		}
@@ -695,7 +762,7 @@ FILE *dictopen(const char *filename, const char *how)
 		fh = (FILE *) object_open(fullname, dict_file_open, ud);
 		free(fullname);
 	}
-	else 
+	else
 	{
 		fh = (FILE *) object_open(filename, dict_file_open, ud);
 		if (path_found)
@@ -707,6 +774,60 @@ FILE *dictopen(const char *filename, const char *how)
 	return fh;
 }
 
+/* ======================================================== */
+
+/**
+ * Read in the whole stinkin file.
+ * We read it as wide chars, one char at a time, so that any LC_CTYPE
+ * setting are obeyed.  Later, during dictionary grokking, thesse will
+ * be converted to the internal UTF8 format.
+ */
+wchar_t *get_file_contents(const char * dict_name)
+{
+	int fd;
+	size_t tot_size;
+	int left;
+	struct stat buf;
+	wchar_t * contents, *p;
+
+	FILE *fp = dictopen(dict_name, "r");
+	if (fp == NULL)
+		return NULL;
+
+	/* Get the file size, in bytes. */
+	fd = fileno(fp);
+	fstat(fd, &buf);
+	tot_size = buf.st_size;
+
+	/* This is surely more than we need. But that's OK, better
+	 * too much than too little.  */
+	contents = (wchar_t *) malloc(sizeof(wchar_t) * (tot_size+1));
+
+	/* Now, read the whole file. */
+	p = contents;
+	left = tot_size + 1;
+	while (1)
+	{
+		wchar_t *rv = fgetws(p, left, fp);
+		if (NULL == rv || feof(fp))
+			break;
+		while (*p != 0x0) { p++; left--; }
+		if (left < 0)
+			 break;
+	}
+
+  	fclose(fp);
+
+	if (left < 0)
+	{
+		prt_error("Fatal Error: File size is insane!\n");
+		exit(1);
+	}
+
+	return contents;
+}
+
+
 /* ======================================================== */
 /* Locale routines */
 
