@@ -73,12 +73,17 @@
 /* No langinfo in Windows or MinGW */
 #define nl_langinfo(X) ""
 
-/* strtok_r is missing in Windows */
+/* strtok_r() is missing in Windows */
 char * strtok_r (char *s, const char *delim, char **saveptr);
 
-/* Windows doesn't have a thread-safe rand (???) */
-/* Surely not, there must be something */
-/* XXX FIXME -- this breaks thread safety on windows */
+/* strndup() is missing in Windows. */
+char * strndup (const char *str, size_t size);
+
+/* Windows doesn't have a thread-safe rand (!)
+ * XXX FIXME -- this breaks thread safety on windows!
+ * That means YOU, windows thread-using programmer!
+ * Suck it up!
+ */
 #define rand_r(seedp) rand()
 #endif /* _MSC_VER || __MINGW32__ */
 
@@ -97,7 +102,7 @@ char * strtok_r (char *s, const char *delim, char **saveptr);
 #define iswdigit  isdigit
 #define iswspace  isspace
 #define wchar_t   char
-#define wint_t    int
+#define wint_t    unsigned int  /* I think ?? not sure */
 #define fgetwc    fgetc
 #define WEOF      EOF
 #define towlower  tolower
@@ -274,6 +279,8 @@ void * object_open(const char *filename,
                    void * (*opencb)(const char *, void *),
                    void * user_data);
 
+wchar_t * get_file_contents(const char *filename);
+
 /**
  * Returns the smallest power of two that is at least i and at least 1
  */
