@@ -17,17 +17,8 @@ namespace viterbi {
 
 // Classes that convert run-time atom types into compile-time static
 // types, so that the compiler can check these for correctness.
-
-#if 0
-// Atom types.  Right now an enum, but maybe should be dynamic!?
-enum AtomType
-{
-	// Link types
-	AND,        // ordered AND of all children (order is important!)
-	OR,         // unordered OR of all children
-	WORD_DISJ,  // word, followed by a single disjunct for that word.
-};
-#endif
+// These are here purely for C++ programming convenience; the true
+// structure that matters is the dynamic run-time (hyper-)graphs.
 
 class Connector : public Node
 {
@@ -70,7 +61,38 @@ class Word : public Node
 		{}
 };
 
+#if 0
+// Atom types.  Right now an enum, but maybe should be dynamic!?
+enum AtomType
+{
+	// Link types
+	OR,         // unordered OR of all children
+	WORD_DISJ,  // word, followed by a single disjunct for that word.
+};
+#endif
 
+
+/// Ordered sequence
+/// And could/should inherit fom Seq, since the order of the atoms in
+/// its outgoing set is important.
+class And : public Link
+{
+	public:
+		And()
+			: Link(AND)
+		{}
+		And(const OutList& ol)
+			: Link(AND, ol)
+		{}
+};
+
+/// Create a ling-grammar link. This will be of the form:
+///     LING:
+///        Ling_TYPE "MVa"
+///        Atom ...
+///        Atom ...
+/// where the Atoms are typically either connectors, or WORD_DISJ
+///
 class Ling : public Link
 {
 	public:
@@ -81,20 +103,20 @@ class Ling : public Link
 			assert(ol[0]->get_type() == LING_TYPE, "LG link has bad first node");
 		}
 		Ling(const std::string& str, Atom* a, Atom *b)
-			: Link(LING, ({OutList ol;
-				ol.push_back(new LingType(str));
-				ol.push_back(a);
-				ol.push_back(b);
-				ol; }))
-		{}
+			: Link(LING)
+		{
+			_oset.push_back(new LingType(str));
+			_oset.push_back(a);
+			_oset.push_back(b);
+		}
 
 		Ling(LingType* t, Atom* a, Atom *b)
-			: Link(LING, ({OutList ol;
-				ol.push_back(t);
-				ol.push_back(a);
-				ol.push_back(b);
-				ol; }))
-		{}
+			: Link(LING)
+		{
+			_oset.push_back(t);
+			_oset.push_back(a);
+			_oset.push_back(b);
+		}
 
 		LingType* get_ling_type()
 		{
@@ -142,10 +164,15 @@ class WordCset : public Link
 		}
 };
 
-// Ordered sequence
+/// Ordered sequence
+/// Seq inherits fom Link, and is an ordered sequence of zero or more
+/// atoms.
 class Seq : public Link
 {
 	public:
+		Seq()
+			: Link(SEQ)
+		{}
 		Seq(const OutList& ol)
 			: Link(SEQ, ol)
 		{}
@@ -154,7 +181,9 @@ class Seq : public Link
 		{}
 };
 
-// Unordered sequence
+/// Unordered sequence
+/// A Set inherits fom Link, and is an unordered set of zero or more
+/// atoms.
 class Set : public Link
 {
 	public:
@@ -166,6 +195,29 @@ class Set : public Link
 		{}
 };
 
+/// A pair of two sequences.  The first sequence is the state, the
+/// second sequence is the output.  That is, the link created is of the
+/// form
+///
+///    STATE_PAIR :
+///       SEQ
+///           ...
+///       SEQ
+///           ...
+///
+class StatePair : public Link
+{
+	public:
+		StatePair(Seq* stat, Seq* outp)
+			: Link(STATE_PAIR)
+		{
+			_oset.push_back(stat);
+			_oset.push_back(outp);
+		}
+		Seq* get_state() { return dynamic_cast<Seq*>(_oset.at(0)); }
+		Seq* get_output() { return dynamic_cast<Seq*>(_oset.at(1)); }
+};
+
 
 } // namespace viterbi
 } // namespace link-grammar
