@@ -18,22 +18,26 @@ class Connect
 {
 	public:
 		Connect(WordCset*);
-		Set* try_connect(WordCset*);
+		Set* try_connect(StatePair*);
 
 	protected:
+		Set* try_connect(Seq*);
+		Set* next_connect(WordCset*);
+
 		Set* reassemble(Set*, WordCset*, WordCset*);
 		Ling* reassemble(Ling*, WordCset*, WordCset*);
 
-		Link* conn_connect_aa(WordCset*, Atom*, Atom*);
-		Link* conn_connect_na(WordCset*, Connector*, Atom*);
-		Set* conn_connect_ka(WordCset*, Link*, Atom*);
+		Link* conn_connect_aa(Atom*, Atom*);
+		Link* conn_connect_na(Connector*, Atom*);
+		Set* conn_connect_ka(Link*, Atom*);
 
-		Ling* conn_connect_nn(WordCset*, Connector*, Connector*);
-		Link* conn_connect_nk(WordCset*, Connector*, Link*);
+		Ling* conn_connect_nn(Connector*, Connector*);
+		Link* conn_connect_nk(Connector*, Link*);
 
 		static const OutList& flatten(OutList&);
 
 	private:
+		Seq* _left_sequence;
 		WordCset* _right_cset;
 		Atom* _rcons;
 };
