@@ -11,6 +11,7 @@
 #include <string>
 
 #include "atom.h"
+#include "compile.h"
 
 namespace link_grammar {
 namespace viterbi {
@@ -19,6 +20,7 @@ bool conn_match(const std::string&, const std::string&);
 std::string conn_merge(const std::string&, const std::string&);
 bool is_optional(Atom *);
 
+WordCset* cset_trim_left_pointers(WordCset*);
 
 } // namespace viterbi
 } // namespace link-grammar
