@@ -22,6 +22,7 @@ using namespace link_grammar::viterbi;
 #define Lynk link_grammar::viterbi::Link
 
 #define ANODE(TYPE,NAME) (new Node(TYPE,NAME))
+#define ALINK0(TYPE) (new Lynk(TYPE))
 #define ALINK1(TYPE,A) (new Lynk(TYPE, A))
 #define ALINK2(TYPE,A,B) (new Lynk(TYPE, A,B))
 #define ALINK3(TYPE,A,B,C) (new Lynk(TYPE, A,B,C))
@@ -32,7 +33,9 @@ int total_tests = 0;
 // A simple hello test; several different dictionaries
 // should give exactly the same output.  The input sentence
 // is just one word, it should connect to the left-wall in
-// just one way.
+// just one way. The result should be just one alternative:
+// that alternatives has an empty state, and output with
+// just one link.
 bool test_hello(const char *id, const char *dict_str)
 {
 	total_tests++;
@@ -45,37 +48,36 @@ bool test_hello(const char *id, const char *dict_str)
 	parser.streamin("Hello");
 
 	// This is the expected output, no matter what the
-	// dictionary may be.
-	Lynk* ans =
-	ALINK1(SET,
-		ALINK3(LING,
-			ANODE(LING_TYPE, "Wd"),
-			ALINK2(WORD_DISJ,
-				ANODE(WORD, "LEFT-WALL"),
-				ANODE(CONNECTOR, "Wd+")
-			),
-			ALINK2(WORD_DISJ,
-				ANODE(WORD, "Hello"),
-				ANODE(CONNECTOR, "Wd-")
-			)
+	// dictionary may be.  Its just one word, connected to the wall.
+	Lynk* one_word =
+	ALINK3(LING,
+		ANODE(LING_TYPE, "Wd"),
+		ALINK2(WORD_DISJ,
+			ANODE(WORD, "LEFT-WALL"),
+			ANODE(CONNECTOR, "Wd+")
+		),
+		ALINK2(WORD_DISJ,
+			ANODE(WORD, "Hello"),
+			ANODE(CONNECTOR, "Wd-")
 		)
 	);
 
-	Lynk* output = parser.get_output_set();
-	if (not (ans->operator==(output)))
+	// This is the expected set of alternatives: just one alternative,
+	// a single, empty state, and the output, above.
+	Lynk* ans =
+	ALINK1(SET,
+		ALINK2(STATE_PAIR,
+			ALINK0(SEQ),
+			ALINK1(SEQ, one_word)
+		)
+	);
+
+	Lynk* alts = parser.get_alternatives();
+	if (not (ans->operator==(alts)))
 	{
 		cout << "Error: test failure on test " << id << endl;
 		cout << "=== Expecting:\n" << ans << endl;
-		cout << "=== Got:\n" << output << endl;
-		return false;
-	}
-
-	Lynk* final_state = parser.get_state();
-	if (0 != final_state->get_arity())
-	{
-		cout << "Error: test failure on test " << id << endl;
-		cout << "Expecting the final state to be the empty set, but found:\n"
-		     << final_state << endl;
+		cout << "=== Got:\n" << alts << endl;
 		return false;
 	}
 
@@ -125,7 +127,7 @@ bool test_simple_optional()
 
 bool test_simple_onereq()
 {
-	return test_hello ("one required link (simple)",
+	return test_hello ("one required link and opt righties (simple)",
 		"LEFT-WALL: Wd+ or Wi+ or Wq+;"
 		"Hello: Wd- & {A+} & {B+} & {C+};"
 	);
@@ -133,12 +135,20 @@ bool test_simple_onereq()
 
 bool test_simple_zeroreq()
 {
-	return test_hello ("zero required links (simple)",
+	return test_hello ("zero required links and opt righties (simple)",
 		"LEFT-WALL: Wd+ or Wi+ or Wq+;"
 		"Hello: {Wd-} & {A+} & {B+} & {C+};"
 	);
 }
 
+bool test_simple_onereq_and_left()
+{
+	return test_hello ("one required link and opt lefties (simple)",
+		"LEFT-WALL: Wd+ or Wi+ or Wq+;"
+		"Hello: Wd- & {A-} & {B-} & {C+};"
+	);
+}
+
 int ntest_simple()
 {
 	size_t num_failures = 0;
@@ -150,6 +160,7 @@ int ntest_simple()
 	if (!test_simple_optional()) num_failures++;
 	if (!test_simple_onereq()) num_failures++;
 	if (!test_simple_zeroreq()) num_failures++;
+	if (!test_simple_onereq_and_left()) num_failures++;
 	return num_failures;
 }
 
@@ -169,33 +180,47 @@ bool test_alternative(const char *id, const char *dict_str)
 	Parser parser(dict);
 	parser.streamin("Hello");
 
-	Lynk* ans =
-	ALINK2(SET,
-		ALINK3(LING,
-			ANODE(LING_TYPE, "Wd"),
-			ALINK2(WORD_DISJ,
-				ANODE(WORD, "LEFT-WALL"),
-				ANODE(CONNECTOR, "Wd+")
-			),
-			ALINK2(WORD_DISJ,
-				ANODE(WORD, "Hello"),
-				ANODE(CONNECTOR, "Wd-")
-			)
+	Lynk* alt_out_one =
+	ALINK3(LING,
+		ANODE(LING_TYPE, "Wd"),
+		ALINK2(WORD_DISJ,
+			ANODE(WORD, "LEFT-WALL"),
+			ANODE(CONNECTOR, "Wd+")
 		),
-		ALINK3(LING,
-			ANODE(LING_TYPE, "Wi"),
-			ALINK2(WORD_DISJ,
-				ANODE(WORD, "LEFT-WALL"),
-				ANODE(CONNECTOR, "Wi+")
-			),
-			ALINK2(WORD_DISJ,
-				ANODE(WORD, "Hello"),
-				ANODE(CONNECTOR, "Wi-")
-			)
+		ALINK2(WORD_DISJ,
+			ANODE(WORD, "Hello"),
+			ANODE(CONNECTOR, "Wd-")
 		)
 	);
 
-	Lynk* output = parser.get_output_set();
+	Lynk* alt_out_two =
+	ALINK3(LING,
+		ANODE(LING_TYPE, "Wi"),
+		ALINK2(WORD_DISJ,
+			ANODE(WORD, "LEFT-WALL"),
+			ANODE(CONNECTOR, "Wi+")
+		),
+		ALINK2(WORD_DISJ,
+			ANODE(WORD, "Hello"),
+			ANODE(CONNECTOR, "Wi-")
+		)
+	);
+
+	// This is the expected set of alternatives: two alternatives,
+	// each with an empty state, and one of the two outputs, above.
+	Lynk* ans =
+	ALINK2(SET,
+		ALINK2(STATE_PAIR,
+			ALINK0(SEQ),
+			ALINK1(SEQ, alt_out_one)
+		),
+		ALINK2(STATE_PAIR,
+			ALINK0(SEQ),
+			ALINK1(SEQ, alt_out_two)
+		)
+	);
+
+	Lynk* output = parser.get_alternatives();
 	if (not (ans->operator==(output)))
 	{
 		cout << "Error: test failure on test " << id << endl;
@@ -204,15 +229,6 @@ bool test_alternative(const char *id, const char *dict_str)
 		return false;
 	}
 
-	Lynk* final_state = parser.get_state();
-	if (0 != final_state->get_arity())
-	{
-		cout << "Error: test failure on test " << id << endl;
-		cout << "Expecting the final state to be the empty set, but found:\n"
-		     << final_state << endl;
-		return false;
-	}
-
 	cout<<"PASS: test_alternative(" << id << ") " << endl;
 	return true;
 }
@@ -302,34 +318,31 @@ bool test_simple_state(const char *id, const char *dict_str)
 	// Expecting more words to follow, so a non-trivial state.
 	parser.streamin("this");
 
-	Lynk* output = parser.get_output_set();
-	if (output)
-	{
-		cout << "Error: test failure on test " << id << endl;
-		cout << "Expecting no output, but found:\n"
-		     << output << endl;
-		return false;
-	}
-
-	Lynk* ans =
-	ALINK1(SET,
-		ALINK2(SEQ,
-			ALINK2(WORD_CSET,
-				ANODE(WORD, "this"),
-				ANODE(CONNECTOR, "Ss*b+")
-			),
-			ALINK2(WORD_CSET,
-				ANODE(WORD, "LEFT-WALL"),
-				ALINK3(OR,
-					ANODE(CONNECTOR, "Wd+"),
-					ANODE(CONNECTOR, "Wi+"),
-					ANODE(CONNECTOR, "Wq+")
-				)
+	Lynk* ans_state =
+	ALINK2(SEQ,
+		ALINK2(WORD_CSET,
+			ANODE(WORD, "this"),
+			ANODE(CONNECTOR, "Ss*b+")
+		),
+		ALINK2(WORD_CSET,
+			ANODE(WORD, "LEFT-WALL"),
+			ALINK3(OR,
+				ANODE(CONNECTOR, "Wd+"),
+				ANODE(CONNECTOR, "Wi+"),
+				ANODE(CONNECTOR, "Wq+")
 			)
 		)
 	);
 
-	Lynk* state = parser.get_state();
+	Lynk* ans =
+	ALINK1(SET,
+		ALINK2(STATE_PAIR,
+			ans_state,
+			ALINK0(SEQ)
+		)
+	);
+
+	Lynk* state = parser.get_alternatives();
 	if (not (ans->operator==(state)))
 	{
 		cout << "Error: test failure on test " << id << endl;
@@ -413,16 +426,14 @@ bool test_short_sent(const char *id, const char *dict_str)
 	Dictionary dict = dictionary_create_from_utf8(dict_str);
 
 	// print_dictionary_data(dict);
+cout<<"xxxxxxxxxxxxxxxxxxxxxxxx last test xxxxxxxxxxxxxxxx" <<endl;
 
 	Parser parser(dict);
 	// Expecting more words to follow, so a non-trivial state.
 	parser.streamin("this is");
 
-	Lynk* output = parser.get_output_set();
-cout<<"output is >>>" << output<<endl;
-
-	Lynk* state = parser.get_state();
-cout<<"state is >>>" << state<<endl;
+	Lynk* output = parser.get_alternatives();
+cout<<"final alts >>>" << output<<endl;
 
 return false;
 
@@ -441,26 +452,39 @@ bool test_short_this()
 
 // ==================================================================
 
-int
-main(int argc, char *argv[])
+void report(int num_failures, bool exit_on_fail)
 {
-	size_t num_failures = 0;
-
-	num_failures += ntest_simple();
-	num_failures += ntest_two();
-	num_failures += ntest_first();
-	if (!test_short_this()) num_failures++;
-
 	if (num_failures)
 	{
 		cout << "Test failures = " << num_failures
 		     << " out of " << total_tests
-		     << " total." << endl;
-		exit(1);
+		     << " total, so far." << endl;
+		if (exit_on_fail)
+			exit(1);
 	}
 
 	cout << "All " << total_tests
-		     << " tests pass." << endl;
+		     << " tests so far pass." << endl;
+}
+
+int
+main(int argc, char *argv[])
+{
+	size_t num_failures = 0;
+	bool exit_on_fail = true;
+
+	num_failures += ntest_simple();
+	report(num_failures, exit_on_fail);
+
+	num_failures += ntest_two();
+	report(num_failures, exit_on_fail);
+
+	num_failures += ntest_first();
+	report(num_failures, exit_on_fail);
+
+	if (!test_short_this()) num_failures++;
+	report(num_failures, exit_on_fail);
+
 	exit (0);
 }
 
